import asyncio
import websockets


async def echo(websocket, path):
    async for message in websocket:
        await websocket.send(message)

print('Serving OCPP on 0.0.0.0 port 8765 (ws://0.0.0.0:8765/) ...')
asyncio.get_event_loop().run_until_complete(websockets.serve(echo,
                                                             '0.0.0.0',
                                                             8765))
asyncio.get_event_loop().run_forever()



import json
import os
import python_jsonschema_objects as pjs
import websocket


class OCPPConnection():
        def __init__(self, url):
            self.url = url
            self.ws = websocket.create_connection(url)

            self.schemas_dict = {}

            schemas_dir = os.path.join(os.path.dirname(__file__),
                                       'OCPP-2.0_part3_schemas/')
            schemas = os.listdir(schemas_dir)

            for schema in schemas:
                    self.schemas_dict[schema] = json.load(
                            open(os.path.join(schemas_dir, schema),
                                 encoding='utf-8-sig'))

        def __enter__(self):
            return self

        def __exit__(self, exc_type, exc_value, traceback):
            self.ws.close()

        def request(self, message, payload):
            """ Send a request message.

            :param message: 
            :param payload: 
            :returns: 
            :rtype: 

            """
            builder = pjs.ObjectBuilder(self.schemas_dict[message +
                                                          'Request_v1p0.json'],
                                        resolved=self.schemas_dict)
            ns = builder.build_classes(standardize_names=False)

            method_name = 'urn_ocpp_cp_2_2018_4_' + message.lower() + 'request'

            method = getattr(ns, method_name)

            t = method().from_json(payload)

            self.ws.send(t.serialize())
            response = self.ws.recv()
            return {'url': self.url, 'data': response}



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="ioe",
    version="0.0.20",
    author="Sergio Alonso",
    author_email="sergio@sergioalonso.es",
    description="The Python Internet of Energy Library",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitlab.com/sergioalonso/ioe",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: Public Domain",
        "Operating System :: POSIX :: Linux",
    ],
    install_requires=[
        'python-jsonschema-objects>9.9',
        "websockets",
        "websocket-client"
    ],
    dependency_links=[
        'git+https://github.com/sergio-alonso/python-jsonschema-objects@draft-handrews-json-schema-01#egg=python-jsonschema-objects-9.9.9',
    ],
    include_package_data=True
)
